@@ -1,26 +1,10 @@
-/*
- * Copyright (C) 2021 Uniontech Technology Co., Ltd.
- *
- * Author:     yeshanshan <yeshanshan@uniontech.com>
- *
- * Maintainer: yeshanshan <yeshanshan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dconfigresource.h"
 #include "dconfigconn.h"
+#include "dconfigrefmanager.h"
 #include "dconfigfile.h"
 #include <QDBusMessage>
 #include <QDBusConnection>
@@ -63,6 +47,11 @@ bool DSGConfigResource::load(const QString &appid, const QString &name, const QS
     return m_config->load(m_localPrefix);
 }
 
+void DSGConfigResource::setSyncRequestCache(ConfigSyncRequestCache *cache)
+{
+    m_syncRequestCache = cache;
+}
+
 DSGConfigConn *DSGConfigResource::connObject(const uint uid)
 {
     return m_conns.value(getConnKey(uid), nullptr);
@@ -100,6 +89,7 @@ DSGConfigConn *DSGConfigResource::createConn(const uint uid)
     QObject::connect(this, &DSGConfigResource::globalValueChanged, this, &DSGConfigResource::onGlobalValueChanged);
     QObject::connect(conn, &DSGConfigConn::globalValueChanged, this, &DSGConfigResource::onGlobalValueChanged);
     QObject::connect(this, &DSGConfigResource::updateValueChanged, conn, &DSGConfigConn::valueChanged);
+    QObject::connect(conn, &DSGConfigConn::valueChanged, this, &DSGConfigResource::onValueChanged);
     return conn;
 }
 
@@ -178,6 +168,38 @@ void DSGConfigResource::onReleaseChanged(const ConnServiceName &service)
     }
 }
 
+void DSGConfigResource::doSyncConfigCache(const ConfigCacheKey &key)
+{
+    if (ConfigSyncRequestCache::isUserKey(key)) {
+        if (auto conn = m_conns.value(ConfigSyncRequestCache::getUserKey(key))) {
+            qCDebug(cfLog()) << "do sync conn cache for user cache, key:" << key;
+            conn->cache()->save(m_localPrefix);
+        }
+    } else if (ConfigSyncRequestCache::isGlobalKey(key)) {
+        if (ConfigSyncRequestCache::getGlobalKey(key) == m_path && m_config) {
+            qCDebug(cfLog()) << "do sync conn cache for global cache, key:" << key;
+            m_config->save(m_localPrefix);
+        }
+    } else {
+        qCWarning(cfLog()) << "it's not exist config cache key" << key;
+    }
+}
+
+void DSGConfigResource::onValueChanged(const QString &key)
+{
+    if (auto conn = qobject_cast<DSGConfigConn*>(sender())) {
+        do {
+            // global field changed don't cause user field to save, bug `valueChanged` signal is emit.
+            if (m_config && Q_UNLIKELY(m_config->meta()->flags(key).testFlag(DConfigFile::Global)))
+                break;
+
+            if (Q_UNLIKELY(!m_syncRequestCache))
+                break;
+            m_syncRequestCache->pushRequest(ConfigSyncRequestCache::userKey(conn->key()));
+        } while (false);
+    }
+}
+
 QString DSGConfigResource::getConnKey(const uint uid) const
 {
     return QString("%1/%2").arg(m_path).arg(uid);
@@ -257,6 +279,8 @@ void DSGConfigResource::save()
 
 void DSGConfigResource::onGlobalValueChanged(const QString &key)
 {
+    if (m_syncRequestCache)
+        m_syncRequestCache->pushRequest(ConfigSyncRequestCache::globalKey(m_path));
     for (auto conn : m_conns) {
         emit conn->valueChanged(key);
     }
