@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2021 Uniontech Technology Co., Ltd.
- *
- * Author:     yeshanshan <yeshanshan@uniontech.com>
- *
- * Maintainer: yeshanshan <yeshanshan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2021 - 2022 Uniontech Software Technology Co.,Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #pragma once
 
@@ -29,6 +12,8 @@
 
 class DSGConfigResource;
 class RefManager;
+class ConfigSyncBatchRequest;
+class ConfigSyncRequestCache;
 /**
  * @brief The DSGConfigServer class
  * 管理配置策略服务
@@ -80,7 +65,10 @@ private Q_SLOTS:
 
     void onTryExit();
 
+    void doSyncConfigCache(const ConfigSyncBatchRequest &request);
+
 private:
+    ResourceKey getResourceKeyByConfigCache(const ConfigCacheKey &key);
 
     ConfigureId getConfigureIdByPath(const QString &path);
 
@@ -97,4 +85,5 @@ private:
 
     QString m_localPrefix;
     bool m_enableExit = false;
+    ConfigSyncRequestCache *m_syncRequestCache = nullptr;
 };
